OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Không thể ghi vào thư mục \"config\"!",
    "See %s" : "Xem %s",
    "Unknown filetype" : "Không biết kiểu tập tin",
    "Invalid image" : "Hình ảnh không hợp lệ",
    "today" : "hôm nay",
    "yesterday" : "hôm qua",
    "last month" : "tháng trước",
    "_%n month ago_::_%n months ago_" : ["%n tháng trước"],
    "last year" : "năm trước",
    "_%n hour ago_::_%n hours ago_" : ["%n giờ trước"],
    "_%n minute ago_::_%n minutes ago_" : ["%n phút trước"],
    "seconds ago" : "vài giây trước",
    "None" : "Không gì cả",
    "Username" : "Tên đăng nhập",
    "Password" : "Mật khẩu",
    "Apps" : "Ứng dụng",
    "General" : "Tổng hợp",
    "Storage" : "Bộ nhớ",
    "Encryption" : "Mã hóa",
    "Sharing" : "Chia sẻ",
    "Search" : "Tìm kiếm",
    "%s shared »%s« with you" : "%s đã chia sẻ »%s« với bạn",
    "Could not find category \"%s\"" : "không thể tìm thấy mục \"%s\"",
    "Help" : "Giúp đỡ",
    "Settings" : "Cài đặt",
    "Users" : "Người dùng",
    "web services under your control" : "dịch vụ web dưới sự kiểm soát của bạn",
    "Application is not enabled" : "Ứng dụng không được BẬT",
    "Authentication error" : "Lỗi xác thực",
    "Token expired. Please reload page." : "Mã Token đã hết hạn. Hãy tải lại trang."
},
"nplurals=1; plural=0;");
